/*
    Situare - A location system for Facebook
    Copyright (C) 2010  Ixonos Plc. Authors:

        Jussi Laitinen - jussi.laitinen@ixonos.com
        Sami Rämö - sami.ramo@ixonos.com

    Situare is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    version 2 as published by the Free Software Foundation.

    Situare is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Situare; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#include "coordinates/geocoordinate.h"
#include "extendedlistitemdelegate.h"
#include "imagebutton.h"
#include "panelcommon.h"
#include "routewaypointlistitem.h"
#include "routewaypointlistview.h"
#include "routing/location.h"
#include "routing/route.h"

#include "routingpanel.h"

RoutingPanel::RoutingPanel(QWidget *parent)
    : PanelBase(parent)
{
    qDebug() << __PRETTY_FUNCTION__;

    // --- LAYOUT & ROUTING INSTRUCTIONS VIEW ---
    m_routeWaypointListView = new RouteWaypointListView(this);
    m_routeWaypointListView->setItemDelegate(new ExtendedListItemDelegate(this));

    connect(m_routeWaypointListView, SIGNAL(routeWaypointItemClicked(GeoCoordinate)),
            this, SIGNAL(routeWaypointItemClicked(GeoCoordinate)));

    QVBoxLayout *panelLayout = new QVBoxLayout;
    panelLayout->setContentsMargins(PANEL_MARGIN_LEFT, PANEL_MARGIN_TOP,
                                    PANEL_MARGIN_RIGHT, PANEL_MARGIN_BOTTOM);

    panelLayout->addWidget(m_routeWaypointListView);
    setLayout(panelLayout);

    // --- CONTEXT BUTTONS ---
    ImageButton *routeToCursorButton = new ImageButton(":res/images/sight.png",
                                                       "", "", this);
    connect(routeToCursorButton, SIGNAL(clicked()),
            this, SIGNAL(routeToCursor()));

    m_clearRouteButton = new ImageButton(":/res/images/gps_position.png",
                                         "", "", this);
    connect(m_clearRouteButton, SIGNAL(clicked()),
            this, SLOT(clearRouteButtonClicked()));
    m_clearRouteButton->setDisabled(true);

    m_contextButtonLayout->addWidget(routeToCursorButton);
    m_contextButtonLayout->addWidget(m_clearRouteButton);
}

void RoutingPanel::clearListsSelections()
{
    qDebug() << __PRETTY_FUNCTION__;

    m_routeWaypointListView->clearItemSelection();
}

void RoutingPanel::clearRouteButtonClicked()
{
    qDebug() << __PRETTY_FUNCTION__;

    m_clearRouteButton->setDisabled(true);
    m_routeWaypointListView->clearList();
    emit clearRoute();
}

void RoutingPanel::hideEvent(QHideEvent *event)
{
    qDebug() << __PRETTY_FUNCTION__;

    QWidget::hideEvent(event);

    clearListsSelections();
}

void RoutingPanel::setRoute(Route &route)
{
    qDebug() << __PRETTY_FUNCTION__;

    m_routeWaypointListView->clearList();

    QList<RouteSegment> segments = route.segments();
    QList<GeoCoordinate> geometryPoints = route.geometryPoints();

    for (int i = 0; i < segments.size(); ++i) {
        RouteWaypointListItem *item = new RouteWaypointListItem();
        RouteSegment routeSegment = segments.at(i);
        item->setRouteWaypointData(routeSegment,
                                   geometryPoints.at(routeSegment.positionIndex()));

        m_routeWaypointListView->addListItem(QString::number(i), item);
    }

    m_routeWaypointListView->scrollToTop();

    m_clearRouteButton->setDisabled(false);

    emit openPanelRequested(this);
}
